# Go API client for openapi

API to access and control Slurm.

## Overview
This API client was generated by the [OpenAPI Generator](https://openapi-generator.tech) project.  By using the [OpenAPI-spec](https://www.openapis.org/) from a remote server, you can easily generate an API client.

- API version: 0.0.37
- Package version: 1.0.0
- Build package: org.openapitools.codegen.languages.GoClientCodegen
For more information, please visit [https://www.schedmd.com/](https://www.schedmd.com/)

## Installation

Install the following dependencies:

```shell
go get github.com/stretchr/testify/assert
go get golang.org/x/net/context
```

Put the package under your project folder and add the following in import:

```golang
import openapi "github.com/GIT_USER_ID/GIT_REPO_ID"
```

To use a proxy, set the environment variable `HTTP_PROXY`:

```golang
os.Setenv("HTTP_PROXY", "http://proxy_name:proxy_port")
```

## Configuration of Server URL

Default configuration comes with `Servers` field that contains server objects as defined in the OpenAPI specification.

### Select Server Configuration

For using other server than the one defined on index 0 set context value `sw.ContextServerIndex` of type `int`.

```golang
ctx := context.WithValue(context.Background(), openapi.ContextServerIndex, 1)
```

### Templated Server URL

Templated server URL is formatted using default variables from configuration or from context value `sw.ContextServerVariables` of type `map[string]string`.

```golang
ctx := context.WithValue(context.Background(), openapi.ContextServerVariables, map[string]string{
	"basePath": "v2",
})
```

Note, enum values are always validated and all unused variables are silently ignored.

### URLs Configuration per Operation

Each operation can use different server URL defined using `OperationServers` map in the `Configuration`.
An operation is uniquely identified by `"{classname}Service.{nickname}"` string.
Similar rules for overriding default operation server index and variables applies by using `sw.ContextOperationServerIndices` and `sw.ContextOperationServerVariables` context maps.

```golang
ctx := context.WithValue(context.Background(), openapi.ContextOperationServerIndices, map[string]int{
	"{classname}Service.{nickname}": 2,
})
ctx = context.WithValue(context.Background(), openapi.ContextOperationServerVariables, map[string]map[string]string{
	"{classname}Service.{nickname}": {
		"port": "8443",
	},
})
```

## Documentation for API Endpoints

All URIs are relative to *http://localhost/slurm/v0.0.37*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*OpenapiAPI* | [**OpenapiGet**](docs/OpenapiAPI.md#openapiget) | **Get** /openapi | Retrieve OpenAPI Specification
*OpenapiAPI* | [**OpenapiJsonGet**](docs/OpenapiAPI.md#openapijsonget) | **Get** /openapi.json | Retrieve OpenAPI Specification
*OpenapiAPI* | [**OpenapiV3Get**](docs/OpenapiAPI.md#openapiv3get) | **Get** /openapi/v3 | Retrieve OpenAPI Specification
*OpenapiAPI* | [**OpenapiYamlGet**](docs/OpenapiAPI.md#openapiyamlget) | **Get** /openapi.yaml | Retrieve OpenAPI Specification
*SlurmAPI* | [**SlurmctldCancelJob**](docs/SlurmAPI.md#slurmctldcanceljob) | **Delete** /job/{job_id} | cancel or signal job
*SlurmAPI* | [**SlurmctldDiag**](docs/SlurmAPI.md#slurmctlddiag) | **Get** /diag/ | get diagnostics
*SlurmAPI* | [**SlurmctldGetJob**](docs/SlurmAPI.md#slurmctldgetjob) | **Get** /job/{job_id} | get job info
*SlurmAPI* | [**SlurmctldGetJobs**](docs/SlurmAPI.md#slurmctldgetjobs) | **Get** /jobs/ | get list of jobs
*SlurmAPI* | [**SlurmctldGetNode**](docs/SlurmAPI.md#slurmctldgetnode) | **Get** /node/{node_name} | get node info
*SlurmAPI* | [**SlurmctldGetNodes**](docs/SlurmAPI.md#slurmctldgetnodes) | **Get** /nodes/ | get all node info
*SlurmAPI* | [**SlurmctldGetPartition**](docs/SlurmAPI.md#slurmctldgetpartition) | **Get** /partition/{partition_name} | get partition info
*SlurmAPI* | [**SlurmctldGetPartitions**](docs/SlurmAPI.md#slurmctldgetpartitions) | **Get** /partitions/ | get all partition info
*SlurmAPI* | [**SlurmctldGetReservation**](docs/SlurmAPI.md#slurmctldgetreservation) | **Get** /reservation/{reservation_name} | get reservation info
*SlurmAPI* | [**SlurmctldGetReservations**](docs/SlurmAPI.md#slurmctldgetreservations) | **Get** /reservations/ | get all reservation info
*SlurmAPI* | [**SlurmctldPing**](docs/SlurmAPI.md#slurmctldping) | **Get** /ping/ | ping test
*SlurmAPI* | [**SlurmctldSubmitJob**](docs/SlurmAPI.md#slurmctldsubmitjob) | **Post** /job/submit | submit new job
*SlurmAPI* | [**SlurmctldUpdateJob**](docs/SlurmAPI.md#slurmctldupdatejob) | **Post** /job/{job_id} | update job


## Documentation For Models

 - [V0037Diag](docs/V0037Diag.md)
 - [V0037DiagStatistics](docs/V0037DiagStatistics.md)
 - [V0037Error](docs/V0037Error.md)
 - [V0037JobProperties](docs/V0037JobProperties.md)
 - [V0037JobResources](docs/V0037JobResources.md)
 - [V0037JobResponseProperties](docs/V0037JobResponseProperties.md)
 - [V0037JobSubmission](docs/V0037JobSubmission.md)
 - [V0037JobSubmissionResponse](docs/V0037JobSubmissionResponse.md)
 - [V0037JobsResponse](docs/V0037JobsResponse.md)
 - [V0037Node](docs/V0037Node.md)
 - [V0037NodeAllocation](docs/V0037NodeAllocation.md)
 - [V0037NodesResponse](docs/V0037NodesResponse.md)
 - [V0037Partition](docs/V0037Partition.md)
 - [V0037PartitionsResponse](docs/V0037PartitionsResponse.md)
 - [V0037Ping](docs/V0037Ping.md)
 - [V0037Pings](docs/V0037Pings.md)
 - [V0037Reservation](docs/V0037Reservation.md)
 - [V0037ReservationPurgeCompleted](docs/V0037ReservationPurgeCompleted.md)
 - [V0037ReservationsResponse](docs/V0037ReservationsResponse.md)
 - [V0037Signal](docs/V0037Signal.md)


## Documentation For Authorization


Authentication schemes defined for the API:
### user

- **Type**: API key
- **API key parameter name**: X-SLURM-USER-NAME
- **Location**: HTTP header

Note, each API key must be added to a map of `map[string]APIKey` where the key is: X-SLURM-USER-NAME and passed in as the auth context for each request.

Example

```golang
auth := context.WithValue(
		context.Background(),
		sw.ContextAPIKeys,
		map[string]sw.APIKey{
			"X-SLURM-USER-NAME": {Key: "API_KEY_STRING"},
		},
	)
r, err := client.Service.Operation(auth, args)
```

### token

- **Type**: API key
- **API key parameter name**: X-SLURM-USER-TOKEN
- **Location**: HTTP header

Note, each API key must be added to a map of `map[string]APIKey` where the key is: X-SLURM-USER-TOKEN and passed in as the auth context for each request.

Example

```golang
auth := context.WithValue(
		context.Background(),
		sw.ContextAPIKeys,
		map[string]sw.APIKey{
			"X-SLURM-USER-TOKEN": {Key: "API_KEY_STRING"},
		},
	)
r, err := client.Service.Operation(auth, args)
```


## Documentation for Utility Methods

Due to the fact that model structure members are all pointers, this package contains
a number of utility functions to easily obtain pointers to values of basic types.
Each of these functions takes a value of the given basic type and returns a pointer to it:

* `PtrBool`
* `PtrInt`
* `PtrInt32`
* `PtrInt64`
* `PtrFloat`
* `PtrFloat32`
* `PtrFloat64`
* `PtrString`
* `PtrTime`

## Author

sales@schedmd.com

